@@ -37,15 +37,14 @@ from compose.cli import main as docker_compose
 
 from autonomy.cli.fetch import fetch_service
 from autonomy.cli.utils.click_utils import chain_selection_flag
-from autonomy.configurations.constants import DEFAULT_SERVICE_FILE
+from autonomy.configurations.constants import DEFAULT_SERVICE_CONFIG_FILE
 from autonomy.configurations.loader import load_service_config
-from autonomy.constants import DEFAULT_KEYS_FILE
+from autonomy.constants import DEFAULT_BUILD_FOLDER, DEFAULT_KEYS_FILE
 from autonomy.deploy.build import generate_deployment
 from autonomy.deploy.chain import ServiceRegistry
 from autonomy.deploy.constants import (
     AGENT_KEYS_DIR,
     BENCHMARKS_DIR,
-    DEFAULT_ABCI_BUILD_DIR,
     INFO,
     LOGGING_LEVELS,
     LOG_DIR,
@@ -138,6 +137,18 @@ def deploy_group(
     default=False,
     help="Apply environment variable when loading service config.",
 )
+@click.option(
+    "--use-hardhat",
+    is_flag=True,
+    default=False,
+    help="Include a hardhat node in the deployment setup.",
+)
+@click.option(
+    "--use-acn",
+    is_flag=True,
+    default=False,
+    help="Include an ACN node in the deployment setup.",
+)
 @click.option("--image-version", type=str, help="Define runtime image version.")
 @registry_flag()
 @password_option(confirmation_prompt=True)
@@ -158,11 +169,13 @@ def build_deployment_command(  # pylint: disable=too-many-arguments, too-many-lo
     log_level: str = INFO,
     aev: bool = False,
     image_version: Optional[str] = None,
+    use_hardhat: bool = False,
+    use_acn: bool = False,
 ) -> None:
     """Build deployment setup for n agents."""
 
     keys_file = Path(keys_file or DEFAULT_KEYS_FILE).absolute()
-    build_dir = Path(output_dir or DEFAULT_ABCI_BUILD_DIR).absolute()
+    build_dir = Path(output_dir or DEFAULT_BUILD_FOLDER).absolute()
 
     packages_dir = Path(packages_dir or Path.cwd() / "packages").absolute()
     open_aea_dir = Path(open_aea_dir or Path.home() / "open-aea").absolute()
@@ -200,6 +213,8 @@ def build_deployment_command(  # pylint: disable=too-many-arguments, too-many-lo
             log_level=log_level,
             substitute_env_vars=aev,
             image_version=image_version,
+            use_hardhat=use_hardhat,
+            use_acn=use_acn,
         )
     except Exception as e:  # pylint: disable=broad-except
         shutil.rmtree(build_dir)
@@ -276,7 +291,7 @@ def run_deployment_from_token(  # pylint: disable=too-many-arguments, too-many-l
     *_, service_hash = metadata["code_uri"].split("//")
     public_id = PublicId(author="valory", name="service", package_hash=service_hash)
     service_path = fetch_service(ctx, public_id)
-    build_dir = service_path / DEFAULT_ABCI_BUILD_DIR
+    build_dir = service_path / DEFAULT_BUILD_FOLDER
 
     update_multisig_address(service_path, multisig_address)
     service = load_service_config(service_path, substitute_env_vars=aev)
@@ -301,10 +316,11 @@ def run_deployment_from_token(  # pylint: disable=too-many-arguments, too-many-l
     run_deployment(build_dir)
 
 
+# TODO: extract into appropriate utils with validations
 def update_multisig_address(service_path: Path, address: str) -> None:
     """Update the multisig address on the service config."""
 
-    with open_file(service_path / DEFAULT_SERVICE_FILE) as fp:
+    with open_file(service_path / DEFAULT_SERVICE_CONFIG_FILE) as fp:
         config, *overrides = yaml_load_all(
             fp,
         )
@@ -315,11 +331,11 @@ def update_multisig_address(service_path: Path, address: str) -> None:
                 address,
             ]
 
-    with open_file(service_path / DEFAULT_SERVICE_FILE, mode="w+") as fp:
+    with open_file(service_path / DEFAULT_SERVICE_CONFIG_FILE, mode="w+") as fp:
         yaml_dump_all([config, *overrides], fp)
 
 
-def build_deployment(  # pylint: disable=too-many-arguments
+def build_deployment(  # pylint: disable=too-many-arguments, too-many-locals
     keys_file: Path,
     build_dir: Path,
     deployment_type: str,
@@ -334,6 +350,8 @@ def build_deployment(  # pylint: disable=too-many-arguments
     log_level: str = INFO,
     substitute_env_vars: bool = False,
     image_version: Optional[str] = None,
+    use_hardhat: bool = False,
+    use_acn: bool = False,
 ) -> None:
     """Build deployment."""
     if build_dir.is_dir():
@@ -360,6 +378,8 @@ def build_deployment(  # pylint: disable=too-many-arguments
         log_level=log_level,
         substitute_env_vars=substitute_env_vars,
         image_version=image_version,
+        use_hardhat=use_hardhat,
+        use_acn=use_acn,
     )
     click.echo(report)
 
