@@ -21,20 +21,23 @@
 
 import time
 from pathlib import Path
-from typing import Any, Dict
 
 import click
-import yaml
+from aea.configurations.constants import PACKAGES
 
-from autonomy.constants import DEFAULT_BUILD_FOLDER
+from autonomy.constants import DEFAULT_BUILD_FOLDER, DOCKER_COMPOSE_YAML
 from autonomy.deploy.constants import PERSISTENT_DATA_DIR, TM_STATE_DIR
 from autonomy.replay.agent import AgentRunner
 from autonomy.replay.tendermint import build_tendermint_apps
-from autonomy.replay.utils import fix_address_books, fix_config_files
+from autonomy.replay.utils import (
+    fix_address_books,
+    fix_config_files,
+    load_docker_config,
+)
 
 
-REGISTRY_PATH = Path("packages/").absolute()
-BUILD_DIR = Path(DEFAULT_BUILD_FOLDER).absolute()
+REGISTRY_PATH = Path(PACKAGES)
+BUILD_DIR = Path(DEFAULT_BUILD_FOLDER)
 
 
 @click.group(name="replay")
@@ -63,8 +66,10 @@ def run_agent(agent: int, build_path: Path, registry_path: Path) -> None:
     build_path = Path(build_path).absolute()
     registry_path = Path(registry_path).absolute()
 
-    docker_compose_file = build_path / "docker-compose.yaml"
+    docker_compose_file = build_path / DOCKER_COMPOSE_YAML
+    # TODO: handle file not present, file corrupted
     docker_compose_config = load_docker_config(docker_compose_file)
+    # TODO: add JSONSchemaValidator to above loading logic to ensure the below fields are present
     agent_data = docker_compose_config["services"][f"abci{agent}"]
     runner = AgentRunner(agent, agent_data, registry_path)
     try:
@@ -89,6 +94,7 @@ def run_tendermint(build_dir: Path) -> None:
     build_dir = Path(build_dir).absolute()
     dump_dir = build_dir / PERSISTENT_DATA_DIR / TM_STATE_DIR
 
+    # TODO: missing error handling
     fix_address_books(build_dir)
     fix_config_files(build_dir)
 
@@ -104,11 +110,3 @@ def run_tendermint(build_dir: Path) -> None:
         proxy_app.run(host="localhost", port=8080)
     except KeyboardInterrupt:
         tendermint_network.stop()
-
-
-def load_docker_config(file_path: Path) -> Dict[str, Any]:  # pragma: nocover
-    """Load docker config."""
-    with open(str(file_path), "r", encoding="utf-8") as fp:
-        docker_compose_config = yaml.safe_load(fp)
-
-    return docker_compose_config
