@@ -2,6 +2,7 @@
 # ------------------------------------------------------------------------------
 #
 #   Copyright 2021-2022 Valory AG
+#   Copyright 2018-2021 Fetch.AI Limited
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -29,17 +30,18 @@ from typing import Any, Optional, Set, Tuple, Union, cast
 
 import aiohttp
 import certifi  # pylint: disable=wrong-import-order
+from aiohttp.client_reqrep import ClientResponse  # pylint: disable=wrong-import-order
+from multidict import (  # pylint: disable=wrong-import-order
+    CIMultiDict,
+    CIMultiDictProxy,
+)
+
 from aea.common import Address
 from aea.configurations.base import PublicId
 from aea.connections.base import Connection, ConnectionStates
 from aea.exceptions import enforce
 from aea.mail.base import Envelope, Message
 from aea.protocols.dialogue.base import Dialogue as BaseDialogue
-from aiohttp.client_reqrep import ClientResponse  # pylint: disable=wrong-import-order
-from multidict import (  # pylint: disable=wrong-import-order
-    CIMultiDict,
-    CIMultiDictProxy,
-)
 
 from packages.valory.protocols.http.dialogues import HttpDialogue as BaseHttpDialogue
 from packages.valory.protocols.http.dialogues import HttpDialogues as BaseHttpDialogues
@@ -50,7 +52,7 @@ SUCCESS = 200
 NOT_FOUND = 404
 REQUEST_TIMEOUT = 408
 SERVER_ERROR = 500
-PUBLIC_ID = PublicId.from_str("valory/http_client:0.1.0")
+PUBLIC_ID = PublicId.from_str("valory/http_client:0.23.0")
 
 _default_logger = logging.getLogger("aea.packages.valory.connections.http_client")
 
@@ -123,7 +125,7 @@ class HTTPClientAsyncChannel:  # pylint: disable=too-many-instance-attributes
         :param agent_address: the address of the agent.
         :param address: server hostname / IP address
         :param port: server port number
-        :param connection_id: id of the connection
+        :param connection_id: the id of the connection
         """
         self.agent_address = agent_address
         self.address = address
@@ -293,7 +295,7 @@ class HTTPClientAsyncChannel:  # pylint: disable=too-many-instance-attributes
         self._tasks.remove(task)
         self.logger.debug(f"Task completed: {task}")
 
-    async def get_message(self) -> Union["Envelope", None]:
+    async def get_message(self) -> Optional["Envelope"]:
         """
         Get http response from in-queue.
 
@@ -374,7 +376,11 @@ class HTTPClientConnection(Connection):
     connection_id = PUBLIC_ID
 
     def __init__(self, **kwargs: Any) -> None:
-        """Initialize a HTTP client connection."""
+        """
+        Initialize a HTTP client connection.
+
+        :param kwargs: keyword arguments
+        """
         super().__init__(**kwargs)
         host = cast(str, self.configuration.config.get("host"))
         port = cast(int, self.configuration.config.get("port"))
