@@ -2,6 +2,7 @@
 # ------------------------------------------------------------------------------
 #
 #   Copyright 2021-2022 Valory AG
+#   Copyright 2018-2019 Fetch.AI Limited
 #
 #   Licensed under the Apache License, Version 2.0 (the "License");
 #   you may not use this file except in compliance with the License.
@@ -18,17 +19,25 @@
 # ------------------------------------------------------------------------------
 
 """This module contains the tests of the ledger API connection module."""
-
 # pylint: skip-file
 
 import asyncio
 import logging
+import platform
 import time
 from pathlib import Path
 from typing import Any, Dict, Optional, cast
 from unittest.mock import Mock, patch
 
 import pytest
+from aea_ledger_ethereum import EthereumCrypto
+from aea_ledger_ethereum.test_tools.constants import ETHEREUM_PRIVATE_KEY_PATH
+from aea_ledger_ethereum.test_tools.fixture_helpers import (  # noqa: F401 pylint: disable=unsed-import
+    DEFAULT_GANACHE_CHAIN_ID,
+    ganache,
+)
+from web3.eth import Eth
+
 from aea.common import Address
 from aea.configurations.data_types import PublicId
 from aea.connections.base import Connection, ConnectionStates
@@ -44,17 +53,6 @@ from aea.helpers.transaction.base import (
 )
 from aea.mail.base import Envelope, Message
 from aea.protocols.dialogue.base import Dialogue as BaseDialogue
-from aea_ledger_ethereum import EthereumCrypto
-from aea_test_autonomy.configurations import ETHEREUM_KEY_DEPLOYER
-from aea_test_autonomy.docker.base import skip_docker_tests
-from aea_test_autonomy.docker.ganache import DEFAULT_GANACHE_CHAIN_ID
-from aea_test_autonomy.fixture_helpers import (  # pylint: disable=unused-import  # noqa: F401
-    ganache_addr,
-    ganache_configuration,
-    ganache_port,
-    ganache_scope_class,
-)
-from web3.eth import Eth
 
 from packages.valory.connections.ledger.connection import LedgerConnection
 from packages.valory.connections.ledger.ledger_dispatcher import (
@@ -71,11 +69,15 @@ from packages.valory.protocols.ledger_api.message import LedgerApiMessage
 SOME_SKILL_ID = "some/skill:0.1.0"
 PACKAGE_DIR = Path(__file__).parent.parent
 
+skip_docker_tests = pytest.mark.skipif(
+    platform.system() != "Linux",
+    reason="Docker daemon is not available in Windows and macOS CI containers.",
+)
 logger = logging.getLogger(__name__)
 ledger_ids = pytest.mark.parametrize(
     "ledger_id,address",
     [
-        (EthereumCrypto.identifier, EthereumCrypto(ETHEREUM_KEY_DEPLOYER).address),
+        (EthereumCrypto.identifier, EthereumCrypto(ETHEREUM_PRIVATE_KEY_PATH).address),
     ],
 )
 gas_strategies = pytest.mark.parametrize(
@@ -111,7 +113,7 @@ class LedgerApiDialogues(BaseLedgerApiDialogues):
         )
 
 
-@pytest.mark.usefixtures("ganache_scope_class")
+@pytest.mark.usefixtures("ganache")
 @skip_docker_tests
 class TestLedgerDispatcher:
     """Tests for ledger dispatcher."""
@@ -225,13 +227,13 @@ class TestLedgerDispatcher:
         import aea  # noqa # to load registries
 
         crypto1 = make_crypto(
-            EthereumCrypto.identifier, private_key_path=ETHEREUM_KEY_DEPLOYER
+            EthereumCrypto.identifier, private_key_path=ETHEREUM_PRIVATE_KEY_PATH
         )
         crypto2 = make_crypto(EthereumCrypto.identifier)
         ledger_api_dialogues = LedgerApiDialogues(SOME_SKILL_ID)
 
         amount = 40000
-        fee = 10 ** 7
+        fee = 10**7
 
         # Create ledger_api dialogue: get raw transaction
         request, ledger_api_dialogue = ledger_api_dialogues.create(
@@ -283,13 +285,13 @@ class TestLedgerDispatcher:
         ledger_api_dialogues = LedgerApiDialogues(SOME_SKILL_ID)
 
         crypto1 = make_crypto(
-            EthereumCrypto.identifier, private_key_path=ETHEREUM_KEY_DEPLOYER
+            EthereumCrypto.identifier, private_key_path=ETHEREUM_PRIVATE_KEY_PATH
         )
         crypto2 = make_crypto(EthereumCrypto.identifier)
 
         # First, send a transaction so we can get a digest at the end
         amount = 40000
-        fee = 10 ** 7
+        fee = 10**7
 
         request, ledger_api_dialogue = ledger_api_dialogues.create(
             counterparty=str(ledger_apis_connection.connection_id),
