@@ -410,7 +410,7 @@ class TestTendermintHandler:
     def test_handle_response_invalid_addresses(self, caplog: LogCaptureFixture) -> None:
         """Test handle response invalid address"""
         validator_config = self.dummy_validator_config
-        validator_config[self.agent_name]["tendermint_url"] = "sudo rm -rf /"
+        validator_config[self.agent_name]["tendermint_url"] = "http://some.random.uri"
         performative = TendermintMessage.Performative.RESPONSE
         info = json.dumps(validator_config[self.agent_name])
         message = TendermintMessage(performative, info=info)  # type: ignore
