@@ -75,7 +75,7 @@ class HelloWorldAbciFSMBehaviourBaseCase(BaseSkillTestCase):
     benchmark_dir: TemporaryDirectory
 
     @classmethod
-    def setup(cls, **kwargs: Any) -> None:
+    def setup_class(cls, **kwargs: Any) -> None:
         """Setup the test class."""
         # we need to store the current value of the meta-class attribute
         # _MetaPayload.transaction_type_to_payload_cls, and restore it
@@ -85,7 +85,7 @@ class HelloWorldAbciFSMBehaviourBaseCase(BaseSkillTestCase):
             _MetaPayload.transaction_type_to_payload_cls
         )
         _MetaPayload.transaction_type_to_payload_cls = {}
-        super().setup()
+        super().setup_class()
         assert cls._skill.skill_context._agent_context is not None
         cls._skill.skill_context._agent_context.identity._default_address_key = (
             "ethereum"
@@ -100,20 +100,29 @@ class HelloWorldAbciFSMBehaviourBaseCase(BaseSkillTestCase):
             SigningHandler, cls._skill.skill_context.handlers.signing
         )
 
-        cls.hello_world_abci_behaviour.setup()
-        cls._skill.skill_context.state.setup()
-        cls._skill.skill_context.state.round_sequence.end_sync()
+    def setup(self, **kwargs: Any) -> None:
+        """
+        Set up the test method.
 
-        cls.benchmark_dir = TemporaryDirectory()
-        cls._skill.skill_context.benchmark_tool.log_dir = Path(cls.benchmark_dir.name)
+        Called each time before a test method is called.
+
+        :param kwargs: the keyword arguments passed to _prepare_skill
+        """
+        super().setup()
+        self.hello_world_abci_behaviour.setup()
+        self._skill.skill_context.state.setup()
+        self._skill.skill_context.state.round_sequence.end_sync()
+
+        self.benchmark_dir = TemporaryDirectory()
+        self._skill.skill_context.benchmark_tool.log_dir = Path(self.benchmark_dir.name)
 
         assert (
             cast(
-                BaseBehaviour, cls.hello_world_abci_behaviour.current_behaviour
+                BaseBehaviour, self.hello_world_abci_behaviour.current_behaviour
             ).behaviour_id
-            == cls.hello_world_abci_behaviour.initial_behaviour_cls.behaviour_id
+            == self.hello_world_abci_behaviour.initial_behaviour_cls.behaviour_id
         )
-        cls.synchronized_data = SynchronizedData(
+        self.synchronized_data = SynchronizedData(
             AbciAppDB(
                 setup_data=dict(
                     most_voted_keeper_address=["most_voted_keeper_address"],
@@ -295,10 +304,14 @@ class HelloWorldAbciFSMBehaviourBaseCase(BaseSkillTestCase):
             assert current_behaviour.is_done()
 
     @classmethod
-    def teardown(cls) -> None:
+    def teardown_class(cls) -> None:
         """Teardown the test class."""
         _MetaPayload.transaction_type_to_payload_cls = cls.old_tx_type_to_payload_cls  # type: ignore
-        cls.benchmark_dir.cleanup()
+
+    def teardown(self) -> None:
+        """Teardown."""
+        super().teardown()
+        self.benchmark_dir.cleanup()
 
 
 class BaseSelectKeeperBehaviourTest(HelloWorldAbciFSMBehaviourBaseCase):
