@@ -49,7 +49,6 @@ from packages.valory.skills.registration_abci.behaviours import (
     RegistrationBaseBehaviour,
     RegistrationBehaviour,
     RegistrationStartupBehaviour,
-    format_genesis_data,
 )
 from packages.valory.skills.registration_abci.rounds import (
     BaseSynchronizedData as RegistrationSynchronizedData,
@@ -60,7 +59,8 @@ from packages.valory.skills.registration_abci.rounds import (
     FinishedRegistrationRound,
 )
 
-from tests.conftest import ROOT_DIR
+
+PACKAGE_DIR = Path(__file__).parent.parent
 
 
 SERVICE_REGISTRY_ADDRESS = "0xa51c1fc2f0d1a1b8494ed1fe312d7c3a78ed91c0"
@@ -93,7 +93,7 @@ def as_context(*contexts: Any) -> Generator[None, None, None]:
 class RegistrationAbciBaseCase(FSMBehaviourBaseCase):
     """Base case for testing RegistrationAbci FSMBehaviour."""
 
-    path_to_skill = Path(ROOT_DIR, "packages", "valory", "skills", "registration_abci")
+    path_to_skill = PACKAGE_DIR
 
 
 class BaseRegistrationTestBehaviour(RegistrationAbciBaseCase):
@@ -295,7 +295,9 @@ class TestRegistrationStartupBehaviour(RegistrationAbciBaseCase):
     def mock_tendermint_update(self, valid_response: bool = True) -> None:
         """Mock Tendermint update"""
 
-        validator_configs = format_genesis_data(self.state.registered_addresses)
+        validator_configs = self.state.format_genesis_data(
+            self.state.registered_addresses
+        )
         body = json.dumps(validator_configs).encode(self.state.ENCODING)
         url = self.state.tendermint_parameter_url
         request_kwargs = dict(method="POST", url=url, body=body)
@@ -327,6 +329,7 @@ class TestRegistrationStartupBehaviour(RegistrationAbciBaseCase):
         """Empty init"""
         assert self.state.registered_addresses == {}
         assert self.state.local_tendermint_params == {}
+        assert self.state.updated_genesis_data == {}
 
     def test_no_contract_address(self, caplog: LogCaptureFixture) -> None:
         """Test service registry contract address not provided"""
@@ -458,6 +461,7 @@ class TestRegistrationStartupBehaviour(RegistrationAbciBaseCase):
     ) -> None:
         """Test Tendermint config update"""
 
+        self.state.updated_genesis_data = {}
         failed_message = self.state.LogMessages.failed_update
         response_message = self.state.LogMessages.response_update
         log_message = [failed_message, response_message][valid_response]
@@ -479,6 +483,7 @@ class TestRegistrationStartupBehaviour(RegistrationAbciBaseCase):
         self, valid_response: bool, caplog: LogCaptureFixture
     ) -> None:
         """Test Tendermint start"""
+        self.state.updated_genesis_data = {}
         with as_context(
             caplog.at_level(logging.INFO, logger=self.logger),
             self.mocked_service_registry_address,
