@@ -69,7 +69,7 @@ class TransactionParams(BaseParams):  # pylint: disable=too-many-instance-attrib
         self.tx_hash: str = ""
         self.nonce: Optional[Nonce] = None
         self.gas_price: Optional[Dict[str, Wei]] = None
-        self.fallback_gas: int = 0
+        self.fallback_gas: int = kwargs.pop("init_fallback_gas", 0)
         self.late_messages: List[ContractApiMessage] = []
         self.keeper_allowed_retries: int = self._ensure(
             "keeper_allowed_retries", kwargs
