@@ -45,28 +45,15 @@ AGENT_DATA = {
     "mem_reservation": "256M",
     "cpus": 1,
     "container_name": "abci0",
-    "image": "valory/open-autonomy-open-aea:oracle-0.1.0",
+    "image": "valory/open-autonomy-open-aea:hello-world-0.1.0",
     "environment": [
         "LOG_FILE=/logs/aea_0.txt",
         "ID=0",
-        "VALORY_APPLICATION=valory/oracle:0.1.0:QmUTuBXUbgBjBbiLR3kmBxZXQowseu2mc6xR5MVuX8UyXJ",
+        "VALORY_APPLICATION=valory/hello_world:0.1.0:bafybeideb6b5k4i6z7bm3p53eydxgknmwdefo2oshcnlxthjc6oxeox7ua",
         "ABCI_HOST=abci0",
         "MAX_PARTICIPANTS=4",
         "TENDERMINT_URL=http://node0:26657",
         "TENDERMINT_COM_URL=http://node0:8080",
-        "SKILL_ORACLE_ABCI_MODELS_PRICE_API_ARGS_URL=https://api.coingecko.com/api/v3/simple/price",
-        "SKILL_ORACLE_ABCI_MODELS_PRICE_API_ARGS_API_ID=coingecko",
-        'SKILL_ORACLE_ABCI_MODELS_PRICE_API_ARGS_PARAMETERS=[["ids", "bitcoin"], ["vs_currencies", "usd"]]',
-        "SKILL_ORACLE_ABCI_MODELS_PRICE_API_ARGS_RESPONSE_KEY=bitcoin:usd",
-        "SKILL_ORACLE_ABCI_MODELS_PRICE_API_ARGS_HEADERS=None",
-        "SKILL_ORACLE_ABCI_MODELS_RANDOMNESS_API_ARGS_URL=https://drand.cloudflare.com/public/latest",
-        "SKILL_ORACLE_ABCI_MODELS_RANDOMNESS_API_ARGS_API_ID=cloudflare",
-        "SKILL_ORACLE_ABCI_MODELS_PARAMS_ARGS_OBSERVATION_INTERVAL=30",
-        "SKILL_ORACLE_ABCI_MODELS_PARAMS_ARGS_BROADCAST_TO_SERVER=False",
-        "SKILL_ORACLE_ABCI_MODELS_PARAMS_ARGS_SERVICE_REGISTRY_ADDRESS=0x0DCd1Bf9A1b36cE34237eEaFef220932846BCD82",
-        "SKILL_ORACLE_ABCI_MODELS_PARAMS_ARGS_ON_CHAIN_SERVICE_ID=1",
-        "SKILL_ORACLE_ABCI_MODELS_SERVER_API_ARGS_URL=https://oracle-server.staging.autonolas.tech/deposit",
-        "SKILL_ORACLE_ABCI_MODELS_BENCHMARK_TOOL_ARGS_LOG_DIR=/benchmarks",
         "LEDGER_ADDRESS=http://143.110.184.220:8545",
         "LEDGER_CHAIN_ID=31337",
         "AEA_KEY=0x874741e86698d72ce5a579386ab6f3e006426e4959662736aa3132b83911130a",
