@@ -51,6 +51,7 @@ ENCODING = "utf-8"
 VERSION = "0.34.19"
 
 wait_for_node_to_run = pytest.mark.usefixtures("wait_for_node")
+wait_for_occupied_rpc_port = pytest.mark.usefixtures("wait_for_occupied_rpc_port")
 
 
 # utility functions
@@ -194,14 +195,10 @@ class TestTendermintServerApp(BaseTendermintServerTest):
             response = client.get("/non_existing_endpoint")
             assert response.status_code == 404
 
-    @pytest.mark.skipif(
-        platform.system() == "Windows",
-        reason="this endpoint makes request to the local tendermint node using address 0.0.0.0 which does not work on windows",
-    )
     @wait_for_node_to_run
     def test_get_app_hash(self) -> None:
         """Test get app hash"""
-        time.sleep(3)  # requires some extra time!
+        time.sleep(5)  # requires some extra time!
         with self.app.test_client() as client:
             response = client.get("/app_hash")
             data = response.get_json()
@@ -312,11 +309,7 @@ class TestTendermintBufferFailing(BaseTendermintServerTest):
         ):
             super().setup_class()
 
-    @pytest.mark.skipif(
-        platform.system() == "Windows",
-        reason="Needs investigation. Could be: Tendermint process is not killed on teardown in Windows.",
-    )
-    @wait_for_node_to_run
+    @wait_for_occupied_rpc_port
     def test_tendermint_buffer(self) -> None:
         """Test Tendermint buffer"""
 
